@@ -21,6 +21,12 @@ var entriesOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::- key: 0\n  value: a\n- key: 1\n  value: b\n",
 		},
 	},
+	{
+		description: "to_entries null",
+		document:    `null`,
+		expression:  `to_entries`,
+		expected:    []string{},
+	},
 	{
 		description: "from_entries map",
 		document:    `{a: 1, b: 2}`,
